#
# spec file for package powertop
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           powertop
Version:        2.9
Release:        lp151.2.4
#Git-Clone:	git://github.com/fenrus75/powertop
Summary:        A Linux Tool to Find out What is Using Power on a Laptop
License:        GPL-2.0
Group:          System/Monitoring
Url:            https://01.org/powertop/
Source0:        https://01.org/sites/default/files/downloads/%{name}/%{name}-v%{version}.tar.gz
Source1:        powertop.service
Patch1:         powertop_cstate_fix.patch
Patch2:         powertop_libc++_fix.patch
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(zlib)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
PowerTOP is a program that collects the various pieces of information
from your system and presents an overview of how well your laptop is
doing in terms of power savings.

%lang_package

%prep
%setup -qn powertop-v%{version}
%patch1 -p1
%patch2 -p1

# Delete objects files left in tarball
find . -name '*.o' -delete

%build
export CFLAGS="%{optflags} -D_GNU_SOURCE"
%configure
make %{?_smp_mflags} V=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
install -Dd %{buildroot}%{_localstatedir}/cache/powertop
touch %{buildroot}%{_localstatedir}/cache/powertop/{saved_parameters.powertop,saved_results.powertop}
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/powertop.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%find_lang %{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
# Hack for powertop not to show warnings on first start
touch %{_localstatedir}/cache/powertop/saved_parameters.powertop
touch %{_localstatedir}/cache/powertop/saved_results.powertop

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%doc COPYING README
%dir %{_localstatedir}/cache/powertop
%ghost %{_localstatedir}/cache/powertop/saved_parameters.powertop
%ghost %{_localstatedir}/cache/powertop/saved_results.powertop
%{_sbindir}/%{name}
%{_mandir}/man8/powertop.8.gz
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon Mar 19 2018 mvetter@suse.com
- Remove powertop-no-date.patch: upstreamed
* Fri Dec  1 2017 trenn@suse.de
- Upgrade to version 2.9
  Already mainline:
  D powertop-2.8-potential-segfaults.patch
  D powertop-no-date.patch
  From mainline (after 2.9):
  A powertop_cstate_fix.patch
  A powertop_libc++_fix.patch
* Mon Jun 12 2017 adam.majer@suse.de
- Sync .changes file from SLE -> OBS devel project (bnc#1041572)
* Thu Aug 25 2016 zaitor@opensuse.org
- Add powertop-2.8-potential-segfaults.patch: Fix potential
  segfaults.
- Drop Environment="TERM=xterm" from the systemd service file, it
  is not needed.
- Following the above: Remove xterm/xterm-bin Requires.
* Thu May 26 2016 mlin@suse.com
- Don't requires xterm-bin but xterm if Leap, boo#981780
* Mon Feb 29 2016 mvetter@suse.com
- Change license from GPL-2.0+ to GPL-2.0.
* Wed Feb 24 2016 mvetter@suse.com
- Fate#320264: Adding to SLE.
* Wed Feb 24 2016 mvetter@suse.com
- Require xterm-bin on openSUSE and xterm on other systems.
  xterm was splitted on openSUSE to have fewer dependencies.
- Fixing powertop-no-date.patch: Missed a whitespace between
  program name and version.
* Mon Feb  8 2016 mvetter@suse.com
- Remove patch powertop-1.98-always-create-params.patch:
  * No mention why this is needed. I don't see any reason for
    having it.
* Thu Feb  4 2016 mpluskal@suse.com
- Make building more verbose
- Use optflags when building
* Tue Nov 10 2015 p.drouand@gmail.com
- Update to version 2.8
  * Enable PowerTOP support for: BSW, BDW-H
  * bug-fix: added devices/devreq.h to Makefile
  * Adding support to SKY platforms.
  * Update internal repo with external mainline
  * Android Support
  * Add C7- C10 support for Intel SKY
  * Enabling Intel SKL support
- Remove powertop-fix-crash-with-autotune.patch; fixed on upstream
  release
- Update powertop-no-date.patch
* Mon Apr 27 2015 zaitor@opensuse.org
- Exchange xterm for xterm-bin Requires, as the xterm.desktop file
  is not needed.
* Sun Apr 12 2015 mpluskal@suse.com
- Add systemd dependencies
- Add pre/post macros for service
- Add rcservice symlink
- Remove double depenency on pkg-config
- Cleanup spec file with spec-cleaner
* Sat Apr 11 2015 hillwood@linuxfans.org
- Add a systemd script.
* Sun Feb  8 2015 p.drouand@gmail.com
- Add powertop-fix-crash-with-autotune.patch; Powertop crashes with
  'powertop --auto-tune' (fix bnc#915690)
- Split out translation files
* Tue Dec 16 2014 p.drouand@gmail.com
- Update to version 2.7
  + RAPL: powercap sysfs used for power measurements.
  + Arm support for devfreq stats.
  + Added support to new Intel platforms.
  + Several bug fixes
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Fri Jun  6 2014 thardeck@suse.com
- Update to version 2.6.1
  * Bug-fix:Seg-fault with powertop --html & --csv
  * Update translation files and configuration
  * Changed Look and feel of HTML report
  * Allow compilation with C++11
  * Several bug fixes
* Fri Mar 21 2014 trenn@suse.de
- Update to version 2.5
- Includes fix for cpufreq drivers not exporting scaling_frequencies
  (bnc#869048)
* Tue Sep  3 2013 remur@gmx.net
- Update to version 2.4
  * support for the Intel Haswell ULT CPU counters
  * support for reporting of SATA DEVSLP in the alpm accounting patch
  * RAPL support
* Wed May 15 2013 remur@gmx.net
- Update to version 2.3
  * Maintenance release
- dropped: powertop-2.2-version-fix.patch
- dropped: powertop-2.2-fix-crash-on-readonly-fs.patch
* Tue Jan  1 2013 remur@gmx.net
- Update to version 2.2:
  * Bugfixes
  * Translation updates
  * Interactive mode scrolling
  * Tunables: suggest writing min_power to all SATA ports
- powertop-2.2-version-fix.patch: Fixes displayed version string in ncurses interface
- powertop-2.2-fix-crash-on-readonly-fs.patch: Fixes crash when writing report to RO filesystem
* Thu Aug 30 2012 chenxiaolong@cxl.epac.to
- Remove leftover x86_64 objects during build
* Tue Aug 21 2012 chenxiaolong@cxl.epac.to
- Update to version 2.1:
  * Added Transifex project integration
  * Added localization of the UI with 9 languages in progress and active
  * Support for cores without P-states
  * Support for Intel GPU statistics
  * PowerTOP manual page added
  * Added an option to specify workload to run during measurement
  * Add an option to suppress output to the terminal
  * Added more ARM support assets
  * Synced Traceevent library from the kernel tree for better event parsing
  * Bug fixes and clean ups
* Sat May 12 2012 jengelh@inai.de
- Update to new upstream release 2.0:
  * Interactive mode: redesigned, tab-based user interface with full
  on-demand window refresh support.
  * Reporting mode: PowerTOP v2.0 now allows you to specify not only
  the duration of each test measurement cycle, but the number of
  iterations to measure. PowerTOP can now produce HTML and CSV.
  * Increased WLAN support: PowerTOP now supports multiple
  WLAN interfaces
  * Enhanced i915 driver support
  * More robust battery data acquisition
  * Real time measurement support for USB hot-plug.
* Thu Feb  2 2012 aj@suse.de
- Update to version 1.98:
  * Major rewrite using perf interface with many new options
* Tue Aug 24 2010 trenn@novell.com
- Fix minor build warning:
  powertop.x86_64: W: name-repeated-in-summary C PowerTOP
- Update to version 1.13:
  Features:
  * PowerTOP now supports Runtime Device Power Management, both in terms
    of enabling it via a suggestion as well as collecting statistics for it
  * PowerTOP now has support for reporting which application keeps the
    disk from powersaving mode (worth +/- 0.5W)
  * PowerTOP now has support for reporting AHCI Link power management
    statistics (worth 0.5W - 1W)
  * PowerTOP now supports the Audio power saving statistics so you can see
    if some app keeps your audio out of powersave (0.5W - 1W)
  * PowerTOP reports the use of "Turbo Mode" on Intel processors that
    support this (Core i7 and such)
  Fixes:
  * We should have fixed all suggestions that previously didn't go away
    even though you hit the key to apply them
  * We don't turn on USB power management for USB input devices, they tend
    to break if you do
  * Be smarter about we report ethernet activity in the light of
    multiqueue networking
  * many translation updates
  * Recognize per cpu hpet in timer reporting
  * Various wifi power saving api changes/tweaks taken care of
* Sun May  9 2010 seife@opensuse.org
- update to SVN rev 332:
  * fix wifi code for current kernels
  * show turbo mode explicitly
  * filter out percpu hpet timer wakeup events
  * ignore usb input devices, do not set/read suspend delay
  * add --pids command-line option
  * add HD audio power save suggestion
  * removed obsolete laptop_mode suggestion
  * updated manpage
* Tue Feb  9 2010 ro@suse.de
- fix segfault: increase max lines from 5000 to 8000 for
  /proc/config.gz and abort if reaching limit
* Tue Mar  3 2009 ro@suse.de
- Update to PowerTOP 1.11
- Changes:
  * Fix compilation with PIC
  * polling hint now refers to /dev/cdrom instead of /dev/scd0
  * fix calculations for systems that vary in power draw proc info
  * Display mwait usage
  * fix EOF at input
  * add --version|-v option
  * spelling error in tips.
* Mon Jun 16 2008 thoenig@suse.de
- Update to PowerTOP 1.10
- Changes:
  * USB suspend statistics
  * support for iwl4965 power saving
  * Powertop now reports which C-states are supported by CPU/BIOS
  * Updated translations: ja, pt_BR, hu, id, zh (thanks!)
* Wed Nov  7 2007 thoenig@suse.de
- Update to PowerTOP 1.9
- Changes:
  * add support for mac80211 based wireless power saving
  * improve bluetooth inactivity detection
  * report USB activity (needs 2.6.24-rc kernel)
  * support the newly reported interrupt events in 2.6.24-rc
* Wed Oct 10 2007 thoenig@suse.de
- Update to PowerTOP 1.8
- Changes:
  * add suggestion to increase VM writeback timeout
  * add suggestion to enable INOTIFY in the kernel
  * fix socket fd leak, found by Nikerabbit on #powertop
  * Add support for deferrable timers (Scott Lamb)
  * Add active hint to enable USB autosuspend on Fedora 7
  * Show blue color if the cpu is 25%% or more busy to indicate
    that idle wakeups no longer is the nr 1 power causer
    (Santiago Gala)
  * merge the -d option from Bill Nottingham (Fedora) to allow
    automated collection of data
* Mon Jun 18 2007 thoenig@suse.de
- Update to PowerTOP 1.7
- Changes:
  * add suggestion to disable TV out
  * add suggestion to disable Wake-On-Lan for unused ethernet
  * show P-states (frequencies)
* Sun Jun 10 2007 thoenig@suse.de
- Update to PowerTOP 1.6
- Changes:
  * Add suggestion to rf_kill unused wireless interfaces
  * Propose killing "sealert"; this is a new thing in F7 that wakes
    up 10 times per second for no reason
  * avoid showing the laptop mode hint when on AC - Val Henson
  * suggest enabling noatime to save disk IO's
  * suggest enabling SATA AHCI Link powermanagement
  * suggest enabling the SMP Power Aware Scheduler
* Mon May 28 2007 thoenig@suse.de
- Update to PowerTOP 1.5
- Changes:
  * fix resize-corrupts-screen-content bug
  * add interrupts to the wakeups/second data in the emulated
    (non-mobile) case
  * calculate a long term power usage from battery charge deltas;
    this should help people whos battery doesn't report discharge
    rates, and also will provide a less noisy datapoint
  * Add option to use `kill` on some known power hogs if they are
    actually waking up a lot:
  - beagle (even latest wakes up 10 times/second when not
    indexing)
  - hal (suggest to stop cdrom polling)
  - gnome-power-manager
    These only show if these actually wake up the cpu 'a lot';
    so if these get fixed then the suggestion will not display.
* Sat May 26 2007 schwab@suse.de
- Don't strip binaries.
* Sat May 26 2007 thoenig@suse.de
- Update to PowerTOP 1.4
- Strip binary
- Add man page and localisation for powertop
- Changes:
  * use gettext to allow translation
    (with lots of thanks to the various translators, especially
    to Benjamin Pineau who showed me how to use gettext tools)
  * fix bluethooth-checks-cause-autload-of-bluetooth bug
  * use ncurses (Sebastian Kuzminsky)
  * rotate through the suggestions randomly, so that all of them
    will show over time
  * Fix the CONFIG_SND_AC97_POWER_SAVE check to only report on ac97
    hw
  * report "hidden but suprious" timer ticks (due to missing hpet
    or lack of NO_HZ)
  * check for HPET being present; if not suggest user to toggle in
    BIOS or apply the patch
  * Some suggestions have become "active", you can press a key to
    tune it right away.
  * Add active suggestion to enable AC97 powersave mode at runtime
  * Add active suggestion to enable wireless powersave mode at
    runtime
  * Add active suggestion to enable ondemand
* Tue May 22 2007 thoenig@suse.de
- Update to PowerTOP 1.3
- Remove patch powertop-fix-compiler-warnings-thoenig-02.patch:
  merged upstream
- Changes:
  * Add suggestion for CONFIG_SND_AC97_POWER_SAVE
  * Fix inefficient code for readdir (Vince Pinter)
  * Highlight the worst offenders in bold (Vince Pinter)
  * Fix crash when running on 2.4 kernels (Harald Fernengel)
  * Check fgets() return values (Timom Hoenig @ SuSE)
  * add suggestion to enable laptop mode (when disabled)
  * add suggestion to disable bluetooth when unused
* Tue May 15 2007 thoenig@suse.de
- Update to PowerTOP 1.2 (skipped 1.1)
- Fix battery code to work with both, mA and mW
- Clean up spec file
- Update patch powertop-fix-compiler-warnings-thoenig-02.patch
- Drop patch powertop-respect-rpm-opt-flags-thoenig-01.patch
* Sun May 13 2007 thoenig@suse.de
- Add patch powertop-fix-compiler-warnings-thoenig-01.patch: Make
  compiler warnings about unsued parameters and return values not
  being repected go away.
- Fix whitespaces for %%description
* Sun May 13 2007 thoenig@suse.de
- Initial package submission (PowerTOP 1.0)
- Add patch powertop-respect-rpm-opt-flags-thoenig-01.patch: Fix
  Makefile to respect RPM_OPT_FLAGS
